@@ -28,4 +28,16 @@ test';
         $expected = "test\n".'<?php echo $__env->make(name(foo), \Illuminate\Support\Arr::except(get_defined_vars(), [\'__data\', \'__path\']))->render(); ?>';
         $this->assertEquals($expected, $this->compiler->compileString($string));
     }
+
+    public function testExtendsFirstAreCompiled()
+    {
+        $string = '@extendsFirst([\'foo\', \'milwad\'])
+test';
+        $expected = "test\n".'<?php echo $__env->first([\'foo\', \'milwad\'], \Illuminate\Support\Arr::except(get_defined_vars(), [\'__data\', \'__path\']))->render(); ?>';
+        $this->assertEquals($expected, $this->compiler->compileString($string));
+
+        $string = '@extendsFirst([name(foo), name(milwad)])'."\n".'test';
+        $expected = "test\n".'<?php echo $__env->first([name(foo), name(milwad)], \Illuminate\Support\Arr::except(get_defined_vars(), [\'__data\', \'__path\']))->render(); ?>';
+        $this->assertEquals($expected, $this->compiler->compileString($string));
+    }
 }
